## depthviz: Transform your dive footage with depth tracking

* Original Author: 
    * [Noppanut Ploywong](https://github.com/noppanut15)
* Maintainer: 
    * [Noppanut Ploywong](https://github.com/noppanut15)

## Dependencies

**MoviePy**: Zulko and [other contributors](https://github.com/Zulko/moviepy/graphs/contributors).

**Open Sans font**: Steve Matteson and [other contributors](https://github.com/googlefonts/opensans/graphs/contributors).

## Test dependencies

**pytest**: Holger Krekel and [other contributors](https://github.com/pytest-dev/pytest/blob/main/AUTHORS).

**mypy**: Jukka Lehtosalo and [other contributors](https://github.com/python/mypy/blob/master/CREDITS).

**ruff**: Charlie Marsh and [other contributors](https://github.com/astral-sh/ruff/graphs/contributors).

**interrogate**: Lynn Root and [other contributors](https://github.com/econchick/interrogate/graphs/contributors).

**coverage**: Ned Batchelder and [other contributors](https://github.com/nedbat/coveragepy/blob/master/CONTRIBUTORS.txt).

**cyclonedx-bom**: CycloneDX and [other contributors](https://github.com/CycloneDX/cyclonedx-python/graphs/contributors).


## Contributors

If your code or changes are here, but you are not mentioned, please open an issue. We appreciate your contributions!

* [Noppanut Ploywong](https://github.com/noppanut15)
* [Your name here 🙂]

---
— Made with ❤️ by freedivers, for freedivers. 🌊🤿